aboutsummaryrefslogtreecommitdiff
path: root/azalea/src/pathfinder/mod.rs
diff options
context:
space:
mode:
authormat <27899617+mat-1@users.noreply.github.com>2023-12-04 23:42:49 -0600
committerGitHub <noreply@github.com>2023-12-04 23:42:49 -0600
commit421d8ce2c837e3140d8f866e63032c277b31a413 (patch)
treed5f06fbcd02c24c6b40edd22cbdfda4d6ed6a39f /azalea/src/pathfinder/mod.rs
parentda4afa8ae3afec4cd59b9a19ae1e04818f1763a7 (diff)
downloadazalea-drasl-421d8ce2c837e3140d8f866e63032c277b31a413.tar.xz
Replace Bevy's FixedUpdate with Azalea's GameTick (#119)
* replace bevy FixedUpdate with azalea GameTick * Update to Bevy 0.12.1
Diffstat (limited to 'azalea/src/pathfinder/mod.rs')
-rw-r--r--azalea/src/pathfinder/mod.rs7
1 files changed, 4 insertions, 3 deletions
diff --git a/azalea/src/pathfinder/mod.rs b/azalea/src/pathfinder/mod.rs
index d9a662f2..789efb07 100644
--- a/azalea/src/pathfinder/mod.rs
+++ b/azalea/src/pathfinder/mod.rs
@@ -28,12 +28,13 @@ use azalea_client::inventory::{InventoryComponent, InventorySet};
use azalea_client::movement::MoveEventsSet;
use azalea_client::{StartSprintEvent, StartWalkEvent};
use azalea_core::position::{BlockPos, Vec3};
+use azalea_core::tick::GameTick;
use azalea_entity::metadata::Player;
use azalea_entity::LocalEntity;
use azalea_entity::{Physics, Position};
use azalea_physics::PhysicsSet;
use azalea_world::{InstanceContainer, InstanceName};
-use bevy_app::{FixedUpdate, PreUpdate, Update};
+use bevy_app::{PreUpdate, Update};
use bevy_ecs::event::Events;
use bevy_ecs::prelude::Event;
use bevy_ecs::query::Changed;
@@ -58,9 +59,9 @@ impl Plugin for PathfinderPlugin {
.add_event::<PathFoundEvent>()
.add_event::<StopPathfindingEvent>()
.add_systems(
// putting systems in the FixedUpdate schedule makes them run every Minecraft tick
// (every 50 milliseconds).
- FixedUpdate,
+ GameTick,
(
timeout_movement,
check_node_reached,
@@ -58,9 +59,9 @@ impl Plugin for PathfinderPlugin {
.add_event::<StopPathfindingEvent>()
.add_systems(
- // putting systems in the FixedUpdate schedule makes them run every Minecraft tick
+ // putting systems in the GameTick schedule makes them run every Minecraft tick
// (every 50 milliseconds).